@@ -1,8 +1,8 @@
 <?php
 /**
- * $Horde: nag/data.php,v 1.39.8.4 2005/10/10 00:49:21 selsky Exp $
+ * $Horde: nag/data.php,v 1.39.8.10 2007/01/02 13:55:12 jan Exp $
  *
- * Copyright 2001-2005 Jan Schneider <jan@horde.org>
+ * Copyright 2001-2007 Jan Schneider <jan@horde.org>
  *
  * See the enclosed file COPYING for license information (GPL).  If you
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
@@ -30,11 +30,21 @@ $file_types = array('csv' => _("CSV"),
 
 /* Templates for the different import steps. */
 $templates = array(
-    IMPORT_FILE => array(NAG_TEMPLATES . '/data/import.inc', NAG_TEMPLATES . '/data/export.inc'),
     IMPORT_CSV => array($registry->get('templates', 'horde') . '/data/csvinfo.inc'),
     IMPORT_MAPPED => array($registry->get('templates', 'horde') . '/data/csvmap.inc'),
     IMPORT_DATETIME => array($registry->get('templates', 'horde') . '/data/datemap.inc')
 );
+if (Nag::hasPermission('max_tasks') !== true &&
+    Nag::hasPermission('max_tasks') <= Nag::countTasks()) {
+    $message = @htmlspecialchars(sprintf(_("You are not allowed to create more than %d tasks."), Nag::hasPermission('max_tasks')), ENT_COMPAT, NLS::getCharset());
+    if (!empty($conf['hooks']['permsdenied'])) {
+        $message = Horde::callHook('_perms_hook_denied', array('nag:max_tasks'), 'horde', $message);
+    }
+    $notification->push($message, 'horde.warning', array('content.raw'));
+    $templates[IMPORT_FILE] = array(NAG_TEMPLATES . '/data/export.inc');
+} else {
+    $templates[IMPORT_FILE] = array(NAG_TEMPLATES . '/data/import.inc', NAG_TEMPLATES . '/data/export.inc');
+}
 
 /* Field/clear name mapping. */
 $app_fields = array('name'      => _("Name"),
@@ -121,15 +131,34 @@ if (!$error) {
 
 /* We have a final result set. */
 if (is_array($next_step)) {
+    /* Create a category manager. */
+    require_once 'Horde/Prefs/CategoryManager.php';
+    $cManager = new Prefs_CategoryManager();
+    $categories = $cManager->get();
+
     /* Create a Nag storage instance. */
     $storage = &Nag_Driver::singleton($_SESSION['import_data']['target']);
+    $max_tasks = Nag::hasPermission('max_tasks');
+    $num_tasks = Nag::countTasks();
     foreach ($next_step as $row) {
-        if (is_a($row, 'Horde_iCalendar_vtodo')) {
-          $row = $storage->fromiCalendar($row);
-        } 
-        foreach ($app_fields as $field => $null) {
-            if (!isset($row[$field])) {
-                $row[$field] = '';
+        if ($max_tasks !== true && $num_tasks >= $max_tasks) {
+            $message = @htmlspecialchars(sprintf(_("You are not allowed to create more than %d tasks."), Nag::hasPermission('max_tasks')), ENT_COMPAT, NLS::getCharset());
+            if (!empty($conf['hooks']['permsdenied'])) {
+                $message = Horde::callHook('_perms_hook_denied', array('nag:max_tasks'), 'horde', $message);
+            }
+            $notification->push($message, 'horde.error', array('content.raw'));
+            break;
+        }
+
+        if (!is_array($row)) {
+            if (!is_a($row, 'Horde_iCalendar_vtodo')) {
+                continue;
+            }
+            $row = $storage->fromiCalendar($row);
+            foreach ($app_fields as $field => $null) {
+                if (!isset($row[$field])) {
+                    $row[$field] = '';
+                }
             }
         }
 
@@ -138,13 +167,26 @@ if (is_array($next_step)) {
                                 !empty($row['due']) ? $row['due'] : '',
                                 !empty($row['priority']) ? $row['priority'] : 3,
                                 !empty($row['completed']) ? $row['completed'] : 0,
-                                !empty($row['category']) ? $row['category'] : '');
+                                !empty($row['category']) ? $row['category'] : '',
+                                !empty($row['alarm']) ? $row['alarm'] : 0);
         if (is_a($result, 'PEAR_Error')) {
             break;
         }
+
+        if (!empty($row['category']) &&
+            !in_array($row['category'], $categories)) {
+            $cManager->add($row['category']);
+            $categories[] = $row['category'];
+        }
+
+        $num_tasks++;
     }
 
-    if (is_a($result, 'PEAR_Error')) {
+
+    if (!count($next_step)) {
+        $notification->push(sprintf(_("The %s file didn't contain any tasks."),
+                                    $file_types[$_SESSION['import_data']['format']]), 'horde.error');
+    } elseif (is_a($result, 'PEAR_Error')) {
         $notification->push(sprintf(_("There was an error importing the data: %s"),
                                     $result->getMessage()), 'horde.error');
     } else {
