@@ -7,7 +7,10 @@ require_once 'Horde/Notification/Listener/status.php';
  * Notification_Listener_status:: class to display the messages for
  * Nag's special message type 'nag.alarm'.
  *
- * $Horde: nag/lib/Notification/Listener/status.php,v 1.6.10.1 2004/12/24 05:15:13 chuck Exp $
+ * $Horde: nag/lib/Notification/Listener/status.php,v 1.6.10.5 2005/11/25 16:02:52 jan Exp $
+ *
+ * See the enclosed file COPYING for license information (GPL).  If you
+ * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
  * @since   Nag 2.0
@@ -17,8 +20,6 @@ class Notification_Listener_status_nag extends Notification_Listener_status {
 
     /**
      * Constructor
-     *
-     * @access public
      */
     function Notification_Listener_status_nag()
     {
@@ -37,7 +38,7 @@ class Notification_Listener_status_nag extends Notification_Listener_status {
         $event = $this->getEvent($message);
         switch ($message['type']) {
         case 'nag.alarm':
-            return '<p class="control">' . Horde::img('alarm.png') . '&nbsp;&nbsp;' . $event->getMessage() . '</p>';
+            return '<p class="notice">' . Horde::img('alarm.png') . '&nbsp;&nbsp;' . $event->getMessage() . '</p>';
         }
 
         return parent::getMessage($message);
